#robertoltlibpythonpro

Module to exemplify the creations of releases

'''console 
python3 -m venv .venv 
source .venv/bin/activate
pip install requirements-dev.txt'''

To evaluate code quality: console -> flake8

[![Build Status](https://www.travis-ci.com/Robertolt/robertoltlibpythonpro.svg?branch=main)](https://www.travis-ci.com/Robertolt/robertoltlibpythonpro)
[![Updates](https://pyup.io/repos/github/Robertolt/robertoltlibpythonpro/shield.svg)](https://pyup.io/repos/github/Robertolt/robertoltlibpythonpro/)
[![Python 3](https://pyup.io/repos/github/Robertolt/robertoltlibpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/Robertolt/robertoltlibpythonpro/)